/*************************************************************************
FILENAME: div_analysis_exec.do


Danny Yagan. 2015. yagan@berkeley.edu.

This program creates all of the tables, figures, and numbers reported 
  in the text of:

  Yagan, Danny. Forthcoming. "Capital Tax Reform and the Real Economy: The 
    Effects of the 2003 Dividend Tax Cut." American Economic Review.
  
Before running, follow the steps specified in README_divdo.pdf and 
  overwrite "/SPECIFY/LOCATION/OF/PARENT/DIRECTORY/HERE" in this file with
  the file path being used.
  	

This program is organized into the following sections:

  0. Set library and log file definitions and generate output file templates
  1. Generate analysis samples
  2. Generate tables
  3. Generate figures

The "Generate tables" section generates all statistics that appear in 
  the paper's tables, outputted in CSV format. The "Generate figures" 
  section generates the paper's figures, outputted in EPS format with 
  underlying values outputted in CSV format.
  
Results that are reported only in the text of the manuscript are 
  computed in the code block of the most relevant table or figure, are
  preceded by a comment specifying "manuscript only", and are outputted in 
  div_oneoffstats.txt.
*************************************************************************/



*************************************************************************;
*************************************************************************;
*(0) SET LIBRARY AND LOG FILE DEFINITIONS AND GENERATE OUTPUT FILE TEMPLATES;
*************************************************************************;
*************************************************************************;
*LIBRARY DEFINITIONS;
clear
clear matrix
scalar drop _all
macro drop _all
set mem 2000m
set matsize 800
set more off
global dirroot = "/SPECIFY/LOCATION/OF/PARENT/DIRECTORY/HERE"
global dirdump = "${dirroot}/dump"
global dirdo = "${dirroot}/do"
global dirdta = "${dirroot}/dta"
global dirrawdata = "${dirroot}/rawdata"
global dirout = "${dirroot}/outreg"
cd ${dirdump}
set more off

*LOG FILE DEFINITIONS;
capture log close _all
log using ${dirout}/div_oneoffstats.txt, name(oneoffstats) text replace
log off oneoffstats
log using ${dirout}/div_logfull.txt, name(logfull) text replace
global starttime="$S_TIME" 
disp "${starttime}" 

*OUTPUT FILE TEMPLATES;
clear
gen exhibit=.
format exhibit %16.0g
tostring exhibit, replace
gen column=.
gen row=.
gen yvar=.
format yvar %16.0g
tostring yvar, replace
gen dd=.
gen dd_se=.
gen byvar1premean=.
gen byvar1presd=.
gen byvar0premean=.
gen firms=.
gen firmyears=.
gen r2=.
gen controls=.
gen fes=.
gen clustervar=.
format clustervar %16.0g
tostring clustervar, replace
gen norm=.
gen detrended=.
gen trimqtop=.
format trimqtop %16.0g
tostring trimqtop, replace
gen trimqbot=.
format trimqbot %16.0g
tostring trimqbot, replace
save divout_coeffs, replace

clear
gen exhibit=.
format exhibit %16.0g
tostring exhibit, replace
gen column=.
gen yvar=.
format yvar %16.0g
tostring yvar, replace
gen dd2003=.
gen dd2003_se=.
gen dd2004=.
gen dd2004_se=.
gen dd2005=.
gen dd2005_se=.
gen dd2006=.
gen dd2006_se=.
gen dd2007=.
gen dd2007_se=.
gen dd2008=.
gen dd2008_se=.
gen byvar1premean=.
gen firms=.
gen firmyears=.
gen r2=.
gen controls=.
gen fes=.
gen clustervar=.
format clustervar %16.0g
tostring clustervar, replace
gen norm=.
gen detrended=.
gen trimqtop=.
format trimqtop %16.0g
tostring trimqtop, replace
gen trimqbot=.
format trimqbot %16.0g
tostring trimqbot, replace
save divout_coeffs_yrbyyr, replace

clear
gen var=.
format var %16.0g
tostring var, replace
gen byvar=.
gen freq=.
gen mean=.
gen p10=.
gen p50=.
gen p90=.
save divout_tab1adata, replace



*************************************************************************;
*************************************************************************;
*(1) GENERATE ANALYSIS SAMPLES;
*************************************************************************;
*************************************************************************;

******************************************************************;
                     ************************;
*(1.1) SAVE RAW CSVs AS DTAs;
**soiubp.csv underlies the paper's unbalanced panel. soibp.csv 
** underlies the paper's balanced panel. soiubp.csv and soibp.csv are based on
** on tax records; see README_divdo.pdf.;
                     ************************;
******************************************************************;
insheet using $dirrawdata/soiubp.csv, comma clear
save $dirdta/rawsoiubp, replace
insheet using $dirrawdata/soibp.csv, comma clear
save $dirdta/rawsoibp, replace


******************************************************************;
                     ************************;
*(1.2) SET GLOBALS THAT MAKE USE OF THE GENERAL DFL UTILITY CODE IN ;
*      div_dfl.do;
                     ************************;
******************************************************************;
global divdflvar1 = "nc2dig"
global dflbyvar = "taxyearddccorp"
global dflbyvarbasegroup = 20021
global divdflnumbins = 10
global dflbalanceacrossbyvar = 0


******************************************************************;
                     ************************;
*(1.3) CREATE SOIUBP.DTA (main analysis sample);
                     ************************;
******************************************************************;
*RESTRICT THE SAMPLE AND PREP FOR DFL;
use $dirdta/rawsoiubp, clear
gen ddccorp = ccorplag2
keep if asslag2to1>1000000 & asslag2to1<1000000000 & revlag2to1>500000 & revlag2to1<1500000000
keep if privatelag2==1
global divdflvar2 = "revlag2to1"

*DFL;
gen nodfl = $divdflvar2
gen taxyearddccorp = tax_year*10+ddccorp
global dflorigwgt = "$divdflvar2"
do ${dirdo}/div_analysis_dfldefinebins
do ${dirdo}/div_analysis_dfl
drop dflbin
rename dfl dfl_main

*TRIM CONTROLS;
foreach root in marginblag2to1 revlag2to1gro age {
	sum `root', detail
	replace `root'=r(p99) if `root'>r(p99) & `root'!=.		
	if "`root'"!="age" {
		replace `root'=r(p1) if `root'<r(p1) & `root'!=.
	}
}
foreach root in age lnrevlag2to1 marginblag2to1 revlag2to1gro {
	gen `root'_2 = `root'^2
	gen `root'_3 = `root'^3
	gen `root'_4 = `root'^4
}

*CREATE NEW VARS AND SAVE;
gen double rowid = 10000*tinc + tax_year
format rowid %20.0g
gen ddccorp_byvar=ddccorp
gen ddpost = (tax_year>2002)
gen ddtaxyear = tax_year
gen ddposttaxyear = ddpost*ddtaxyear
gen ddccorppost = ddccorp*ddpost
gen ddccorptaxyear = ddccorp*ddtaxyear
gen ddccorptaxyearpost = ddccorp*ddtaxyear*ddpost
forvalues t=1998/2008 {
	gen i_ty`t' = (tax_year==`t')
	gen dd_i_ty`t' = i_ty`t'
	gen ddccorp_i_ty`t' = ddccorp*dd_i_ty`t'
}
save $dirdta/soiubp, replace


******************************************************************;
                     ************************;
*(1.4) CREATE soibp.dta (balanced panel analysis sample);
                     ************************;
******************************************************************;
*RESTRICT THE SAMPLE AND PREP FOR DFL;
use $dirdta/rawsoibp, clear
gen ddccorp = ccorp96
keep if ass9697>=1000000 & ass9697<=1000000000 & rev9697>=500000 & rev9697<=1500000000
keep if firstpubyr==. | firstpubyr>1997
global divdflvar2 = "rev9697"

*DFL;
gen nodfl = $divdflvar2
gen taxyearddccorp = tax_year*10+ddccorp
global dflorigwgt = "$divdflvar2"
do ${dirdo}/div_analysis_dfldefinebins
do ${dirdo}/div_analysis_dfl
drop dflbin
rename dfl dfl_main

*CREATE NEW VARS AND SAVE;
gen double rowid = 10000*tinc + tax_year
format rowid %20.0g
gen ddccorp_byvar=ddccorp
gen ddpost = (tax_year>2002)
gen ddtaxyear = tax_year
gen ddposttaxyear = ddpost*ddtaxyear
gen ddccorppost = ddccorp*ddpost
gen ddccorptaxyear = ddccorp*ddtaxyear
gen ddccorptaxyearpost = ddccorp*ddtaxyear*ddpost
forvalues t=1998/2008 {
	gen i_ty`t' = (tax_year==`t')
	gen dd_i_ty`t' = i_ty`t'
	gen ddccorp_i_ty`t' = ddccorp*dd_i_ty`t'
}
save $dirdta/soibp, replace


******************************************************************;
                     ************************;
*(1.5) CREATE soiubp_public.dta (main analysis sample without dropping ;
*      public firms);
                     ************************;
******************************************************************;
*RESTRICT THE SAMPLE AND PREP FOR DFL;
use $dirdta/rawsoiubp, clear
gen ddccorp = ccorplag2
keep if asslag2to1>1000000 & asslag2to1<1000000000 & revlag2to1>500000 & revlag2to1<1500000000
global divdflvar2 = "revlag2to1"

*DFL;
gen nodfl = $divdflvar2
gen taxyearddccorp = tax_year*10+ddccorp
global dflorigwgt = "$divdflvar2"
do ${dirdo}/div_analysis_dfldefinebins
do ${dirdo}/div_analysis_dfl
drop dflbin
rename dfl dfl_main

*TRIM CONTROLS;
foreach root in marginblag2to1 revlag2to1gro age {
	sum `root', detail
	replace `root'=r(p99) if `root'>r(p99) & `root'!=.		
	if "`root'"!="age" {
		replace `root'=r(p1) if `root'<r(p1) & `root'!=.
	}
}
foreach root in age lnrevlag2to1 marginblag2to1 revlag2to1gro {
	gen `root'_2 = `root'^2
	gen `root'_3 = `root'^3
	gen `root'_4 = `root'^4
}

*CREATE NEW VARS AND SAVE;
gen double rowid = 10000*tinc + tax_year
format rowid %20.0g
gen ddccorp_byvar=ddccorp
gen ddpost = (tax_year>2002)
gen ddtaxyear = tax_year
gen ddposttaxyear = ddpost*ddtaxyear
gen ddccorppost = ddccorp*ddpost
gen ddccorptaxyear = ddccorp*ddtaxyear
gen ddccorptaxyearpost = ddccorp*ddtaxyear*ddpost
forvalues t=1998/2008 {
	gen i_ty`t' = (tax_year==`t')
	gen dd_i_ty`t' = i_ty`t'
	gen ddccorp_i_ty`t' = ddccorp*dd_i_ty`t'
}
save $dirdta/soiubp_public, replace


******************************************************************;
                     ************************;
*(1.6) CREATE soibp_public.dta (balanced panel analysis sample without ;
*      dropping public firms);
                     ************************;
******************************************************************;
*RESTRICT THE SAMPLE AND PREP FOR DFL;
use $dirdta/rawsoibp, clear
gen ddccorp = ccorp96
keep if ass9697>=1000000 & ass9697<=1000000000 & rev9697>=500000 & rev9697<=1500000000
global divdflvar2 = "rev9697"

*DFL;
gen nodfl = $divdflvar2
gen taxyearddccorp = tax_year*10+ddccorp
global dflorigwgt = "$divdflvar2"
do ${dirdo}/div_analysis_dfldefinebins
do ${dirdo}/div_analysis_dfl
drop dflbin
rename dfl dfl_main

*CREATE NEW VARS AND SAVE;
gen double rowid = 10000*tinc + tax_year
format rowid %20.0g
gen ddccorp_byvar=ddccorp
gen ddpost = (tax_year>2002)
gen ddtaxyear = tax_year
gen ddposttaxyear = ddpost*ddtaxyear
gen ddccorppost = ddccorp*ddpost
gen ddccorptaxyear = ddccorp*ddtaxyear
gen ddccorptaxyearpost = ddccorp*ddtaxyear*ddpost
forvalues t=1998/2008 {
	gen i_ty`t' = (tax_year==`t')
	gen dd_i_ty`t' = i_ty`t'
	gen ddccorp_i_ty`t' = ddccorp*dd_i_ty`t'
}
save $dirdta/soibp_public, replace


******************************************************************;
                     ************************;
*(1.7) CREATE soiubp_publicallbig.dta (main analysis sample without ;
*      dropping public firms or big firms);
                     ************************;
******************************************************************;
*RESTRICT THE SAMPLE AND PREP FOR DFL;
use $dirdta/rawsoiubp, clear
gen ddccorp = ccorplag2
keep if asslag2to1>1000000 & revlag2to1>500000 
global divdflvar2 = "revlag2to1"

*DFL;
gen nodfl = $divdflvar2
gen taxyearddccorp = tax_year*10+ddccorp
global dflorigwgt = "$divdflvar2"
do ${dirdo}/div_analysis_dfldefinebins
do ${dirdo}/div_analysis_dfl
drop dflbin
rename dfl dfl_main

*TRIM CONTROLS;
foreach root in marginblag2to1 revlag2to1gro age {
	sum `root', detail
	replace `root'=r(p99) if `root'>r(p99) & `root'!=.		
	if "`root'"!="age" {
		replace `root'=r(p1) if `root'<r(p1) & `root'!=.
	}
}
foreach root in age lnrevlag2to1 marginblag2to1 revlag2to1gro {
	gen `root'_2 = `root'^2
	gen `root'_3 = `root'^3
	gen `root'_4 = `root'^4
}

*CREATE NEW VARS AND SAVE;
gen double rowid = 10000*tinc + tax_year
format rowid %20.0g
gen ddccorp_byvar=ddccorp
gen ddpost = (tax_year>2002)
gen ddtaxyear = tax_year
gen ddposttaxyear = ddpost*ddtaxyear
gen ddccorppost = ddccorp*ddpost
gen ddccorptaxyear = ddccorp*ddtaxyear
gen ddccorptaxyearpost = ddccorp*ddtaxyear*ddpost
forvalues t=1998/2008 {
	gen i_ty`t' = (tax_year==`t')
	gen dd_i_ty`t' = i_ty`t'
	gen ddccorp_i_ty`t' = ddccorp*dd_i_ty`t'
}
save $dirdta/soiubp_publicallbig, replace

*MANUSCRIPT ONLY: save share of public firm-year observations in 
* soiubp_publicallbig that are in soiubp_public
use tinc tax_year privatelag2 using $dirdta/soiubp_public if privatelag2==0, clear
drop privatelag2
duplicates drop tinc tax_year, force
sort tinc
merge 1:m tinc tax_year using $dirdta/soiubp
keep if _merge==1
sum tinc
global numpubobssmall=r(N)
use tinc tax_year privatelag2 using $dirdta/soiubp_publicallbig if privatelag2==0, clear
drop privatelag2
duplicates drop tinc tax_year, force
sort tinc
merge 1:m tinc tax_year using $dirdta/soiubp
keep if _merge==1
sum tinc
global numpubobssall=r(N)
log on oneoffstats
disp "MANUSCRIPT ONLY: Share of public firms that satisfy size restrictions"
disp ${numpubobssmall}/${numpubobssall}
log off oneoffstats



*************************************************************************;
*************************************************************************;
*(2) CREATE TABLES;
*************************************************************************;
*************************************************************************;

******************************************************************;
                     ************************;
*(2.M1) MAIN TABLE 1;
                     ************************;
******************************************************************;
foreach var in asslag2to1 revlag2to1 inv payout div employeecomp penetlag2to1 penetdiff equityissuedpos age marginblag2to1 revlag2to1gro lass_asslag2to1 liab_asslag2to1 {
  foreach sumstatsbyvar in 0 1 {

    *NOT SCALED
	use dfl_main ddccorp_byvar `var' using $dirdta/soiubp, clear
	keep if dfl_main>0
	keep if ddccorp_byvar==`sumstatsbyvar'
	sum `var', detail
	use divout_tab1adata, clear
	drop if _n>=0
	set obs 1
	replace var="`var'"
	replace byvar=`sumstatsbyvar'
	replace mean=r(mean)
	replace p10=r(p10)
	replace p50=r(p50)
	replace p90=r(p90)
	replace freq=r(N)
	append using divout_tab1adata
	save divout_tab1adata, replace
	
	*SCALED BY revlag2to1
	use dfl_main ddccorp_byvar revlag2to1 `var' using $dirdta/soiubp, clear
	keep if dfl_main>0
	keep if ddccorp_byvar==`sumstatsbyvar'
	replace `var'=`var'/revlag2to1
	sum `var', detail
	use divout_tab1adata, clear
	drop if _n>=0
	set obs 1
	replace var="`var'_revlag2to1"
	replace byvar=`sumstatsbyvar'
	replace mean=r(mean)
	replace p10=r(p10)
	replace p50=r(p50)
	replace p90=r(p90)
	replace freq=r(N)
	append using divout_tab1adata
	save divout_tab1adata, replace

	*SCALED BY penetlag2to1
	use dfl_main ddccorp_byvar penetlag2to1 `var' using $dirdta/soiubp, clear
	keep if dfl_main>0
	keep if ddccorp_byvar==`sumstatsbyvar'
	replace `var'=`var'/penetlag2to1
	sum `var', detail
	use divout_tab1adata, clear
	drop if _n>=0
	set obs 1
	replace var="`var'_penetlag2to1"
	replace byvar=`sumstatsbyvar'
	replace mean=r(mean)
	replace p10=r(p10)
	replace p50=r(p50)
	replace p90=r(p90)
	replace freq=r(N)
	append using divout_tab1adata
	save divout_tab1adata, replace
  }
}
*MANUSCRIPT ONLY: print weighted mean firm size to the log file
use $dirdta/soiubp, clear
log on oneoffstats
disp "MANUSCRIPT ONLY: weighted mean firm size"
format revlag2to1 %15.0f
sum revlag2to1 [w=dfl_main], format
log off oneoffstats

*MANUSCRIPT ONLY: print number of C-corps and S-corps to the log file
use ddccorp_byvar dfl_main tinc using $dirdta/soiubp, clear
keep if dfl_main>0
collapse dfl_main, by(tinc ddccorp_byvar)
collapse (count) freq=dfl_main, by(ddccorp_byvar)
log on oneoffstats
disp "MANUSCRIPT ONLY: number of S-corps and C-corps in unbalanced panel"
list
log off oneoffstats

*MANUSCRIPT ONLY: relative asset intensity and profitability of C-corps
use $dirdta/soiubp, clear
gen ass_rev = asslag2to1/revlag2to1
foreach root in ass_rev {
	sum `root', detail
	replace `root'=r(p5) if `root'<r(p5) & `root'!=.
	replace `root'=r(p95) if `root'>r(p95) & `root'!=.		
}
log on oneoffstats
disp "MANUSCRIPT ONLY: relative asset intensity and profitability of C-corporations"
reg ass_rev i.nc2dig i.tax_year lnrevlag2to1* ddccorp
reg marginblag2to1 i.nc2dig i.tax_year lnrevlag2to1* ddccorp
log off oneoffstats


*MANUSCRIPT ONLY: real aggregate investment changes from NIPA
***investment = real annual aggregate private fixed (i.e. excluding change in inventories) non-res inv (structures+equip+software)
***NOTE: need to use mean because the quarterly and monthly figures are annualized
***NOTE: i use the year definition as in the paper (i.e. year as of july 1)
insheet using ${dirrawdata}/gross_private_fixed_nonres_inv_1111_Monthly.txt, clear
gen newdate = date(observation_date,"YMD")
gen yr = year(newdate)
gen mo = month(newdate)
gen yrmo = yr + mo/12 -1/12
keep if mo==7
sum cpiaucsl_20111116 if yr==2010
replace cpiaucsl_20111116=cpiaucsl_20111116/r(mean)
gen cpi = cpiaucsl_20111116
keep yr cpi
sort yr
save cpi, replace
insheet using ${dirrawdata}/gross_private_fixed_nonres_inv_1111_Quarterly.txt, clear
gen newdate = date(observation_date,"YMD")
gen yr = year(newdate)
gen q = quarter(newdate)
replace yr = yr + q/4 -.25 - .5
replace yr = floor(yr)
collapse (mean) pnfi_20111122, by(yr)
sort yr
merge yr using cpi
replace pnfi_20111122 =  pnfi_20111122/cpi
save nipa_investment, replace
twoway scatter pnfi_20111122 yr if yr>=1988 & yr<2009, ///
	graphregion(fcolor(white)) xtitle("Year") ytitle("Investment (billions $2010)") ///
	c(l) color(navy) xlabel(1988(2)2008) ///
	xline(2002.5, lp(solid) lc(black)) 
graph export "${dirout}/G_slides_agginv_nipa.eps", replace
log on oneoffstats
disp "MANUSCRIPT ONLY: real aggregate investment changes from NIPA"
sum pnfi_20111122 if yr==2007
global postinv = r(mean)
sum pnfi_20111122 if yr==2002
disp $postinv/r(mean)-1
sum pnfi_20111122 if yr==1996
global postinv = r(mean)
sum pnfi_20111122 if yr==1991
disp $postinv/r(mean)-1
log off oneoffstats


*MANUSCRIPT ONLY: estimated private sector employment in 100m-1.5bn range
***divout_oneoffsizerangeemployment.csv is based on tax records; see 
*** README_divdo.pdf. 
**merge tax-data-based firm counts with Census-based firm/employee counts
insheet using ${dirrawdata}/divout_oneoffsizerangeemployment.csv, comma clear
sort bin
save temp, replace
insheet using ${dirrawdata}/div_census_statainsheet.csv, comma clear
sort bin
merge bin using temp
drop _merge
gen c_emp2 = c_emp
**impute estimated number of census firms in the 100m-1.5bn bin
** according to the actual number of tax-data firms in that bin, and the
** tax/census ratio from the 75m-100m bin
gen freqratio = freq/c_freq
sum freqratio if bin==16
replace c_freq=freq/r(mean) if bin==98
**impute number of employees in the 100m-1.5bn bin using emp/numfirms ratio
** from the 75m-100m, allocating the remainder to the >1.5bn bin
gen empratio = c_emp/c_freq
sum empratio if bin==16
replace c_emp=c_freq*r(mean) if bin==98
replace c_freq=c_freq[_n-2]-c_freq[_n-1] if bin==99
replace c_emp=c_emp[_n-2]-c_emp[_n-1] if bin==99
**impute number of employees in the 100m-1.5bn bin using emp/rev ratio
** from the 75m-100m, allocating the remainder to the >1.5bn bin
gen revratio = rev/c_rev
sum revratio if bin==16
replace c_rev=rev/r(mean) if bin==98
gen empratio2 = c_emp/c_rev
sum empratio2 if bin==16
replace c_emp2=c_rev*r(mean) if bin==98
replace c_rev=c_rev[_n-2]-c_rev[_n-1] if bin==99
replace c_emp2=c_emp2[_n-2]-c_emp2[_n-1] if bin==99
**compute statistics for paper
drop if bin==17
sum c_emp
gen empfrac=c_emp/r(sum)
sum c_emp2
gen empfrac2=c_emp2/r(sum)
log on oneoffstats
disp "MANUSCRIPT ONLY: estimated private sector employment in 100m-1.5bn range"
list empfrac* if bin==98
log off oneoffstats





******************************************************************;
                     ************************;
*(2.MT2) MAIN TABLE 2;
                     ************************;
******************************************************************;
global exhibit = "MT2"
global detrend = 0
global dothrough2004only = 0
global doyrbyyr = 0
global norm = 0
global cutvarnewdfl = 0
global dosizehetero = 0
global row = 0


global column = 1
global data = "soiubp"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 2
global data = "soiubp"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 3
global data = "soibp"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 4
global data = "soiubp"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 5
global data = "soiubp"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 6
global data = "soibp"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 7
global data = "soiubp"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 8
global data = "soiubp"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 9
global data = "soibp"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 10
global data = "soiubp"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 11
global data = "soiubp"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 12
global data = "soibp"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg





******************************************************************;
                     ************************;
*(2.MT3) MAIN TABLE 3;
                     ************************;
******************************************************************;
global exhibit = "MT3"
global detrend = 0
global dothrough2004only = 0
global doyrbyyr = 0
global cutvarnewdfl = 1
global dosizehetero = 0
global data = "soiubp"
global trimqtop = "p95"


global column = 1
global yvar = "inv"
global basevarroot = "penet"
global norm = 0
do ${dirdo}/div_analysis_table3loop

global column = 2
global yvar = "penetdiff"
global basevarroot = "penet"
global norm = 0
do ${dirdo}/div_analysis_table3loop

global column = 3
global yvar = "employeecomp"
global basevarroot = "rev"
global norm = 0
do ${dirdo}/div_analysis_table3loop

global column = 4
global yvar = "payout"
global basevarroot = "rev"
global norm = 1
do ${dirdo}/div_analysis_table3loop

global column = 5
global yvar = "equityissuedpos"
global basevarroot = "rev"
global norm = 0
do ${dirdo}/div_analysis_table3loop





******************************************************************;
                     ************************;
*(2.AT1) APPENDIX TABLE 1;
                     ************************;
******************************************************************;
global exhibit = "AT1"
global detrend = 1
global dothrough2004only = 0
global doyrbyyr = 0
global norm = 0
global cutvarnewdfl = 0
global dosizehetero = 0
global row = 0


global column = 1
global data = "soiubp"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 2
global data = "soiubp"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 3
global data = "soibp"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 4
global data = "soiubp"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 5
global data = "soiubp"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 6
global data = "soibp"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 7
global data = "soiubp"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 8
global data = "soiubp"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 9
global data = "soibp"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 10
global data = "soiubp"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 11
global data = "soiubp"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 12
global data = "soibp"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg





******************************************************************;
                     ************************;
*(2.AT2) APPENDIX TABLE 2;
                     ************************;
******************************************************************;
global exhibit = "AT2"
global detrend = 0
global dothrough2004only = 0
global doyrbyyr = 0
global norm = 0
global cutvarnewdfl = 0
global dosizehetero = 0
global row = 0


global column = 1
global data = "soiubp"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 2
global data = "soiubp"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 3
global data = "soibp"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 4
global data = "soiubp"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 5
global data = "soiubp"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 6
global data = "soibp"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 7
global data = "soiubp"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 8
global data = "soiubp"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 9
global data = "soibp"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 10
global data = "soiubp"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 11
global data = "soiubp"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 12
global data = "soibp"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg





******************************************************************;
                     ************************;
*(2.AT3) APPENDIX TABLE 3;
                     ************************;
******************************************************************;
global exhibit = "AT3"
global detrend = 0
global dothrough2004only = 1
global doyrbyyr = 0
global norm = 0
global cutvarnewdfl = 0
global dosizehetero = 0
global row = 0


global column = 1
global data = "soiubp"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 2
global data = "soiubp"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 3
global data = "soibp"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 4
global data = "soiubp"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 5
global data = "soiubp"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 6
global data = "soibp"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 7
global data = "soiubp"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 8
global data = "soiubp"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 9
global data = "soibp"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 10
global data = "soiubp"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 11
global data = "soiubp"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 12
global data = "soibp"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg





******************************************************************;
                     ************************;
*(2.AT4) APPENDIX TABLE 4;
                     ************************;
******************************************************************;
global exhibit = "AT4"
global detrend = 0
global dothrough2004only = 0
global doyrbyyr = 0
global norm = 0
global cutvarnewdfl = 0
global dosizehetero = 0
global row = 0
global trimqtop = "p95"
global yvar = "inv"
global data = "tempsoiubp"


************************;
*COLUMN 2;
************************;
global column = 2
global basevarroot = "penet"
use ${dirdta}/soiubp, clear
keep if (frntxcrlag2==0 | frntxcrlag2==.)
save ${dirdta}/tempsoiubp, replace
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 3;
************************;
global column = 3
global basevarroot = "penet"
use ${dirdta}/soiubp, clear
gen zzcutvar = compolag2/revlag2
pctile zzcutpoints = zzcutvar if ddccorp==1, n(5)
xtile zzcutvarbin = zzcutvar, c(zzcutpoints)
drop if zzcutvarbin==5
drop zz*
save ${dirdta}/tempsoiubp, replace
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 4;
************************;
global column = 4
global basevarroot = "penet"
use ${dirdta}/soiubp, clear
keep if tax_year-age>1986
save ${dirdta}/tempsoiubp, replace
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 5;
************************;
global column = 5
global basevarroot = "penet"
use ${dirdta}/soiubp_publicallbig, clear
save ${dirdta}/tempsoiubp, replace
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 6;
************************;
global column = 6
global basevarroot = "penet"
use ${dirdta}/soiubp, clear
keep if divlag2>0
save ${dirdta}/tempsoiubp, replace
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 7;
************************;
global column = 7
global basevarroot = "penet"
use ${dirdta}/soiubp, clear
pctile zzcutpoints = age if ddccorp==1, n(5)
xtile zzcutvar = age, c(zzcutpoints)
keep if zzcutvar==1
drop zz*
save ${dirdta}/tempsoiubp, replace
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


************************;
*COLUMN 8;
************************;
global column = 8
global basevarroot = "penetss"
global wgt = "dfl_main"

*IDENTIFY CONTINGUOUS-YEAR GROUPS FOR EACH FIRM;
use ${dirdta}/soiubp, clear
tsset tinc tax_year
sort tinc tax_year  
by tinc: gen zztincgroupnum=1 if _n==1
by tinc: replace zztincgroupnum = zztincgroupnum[_n-1] + (L.tax_year==.) if _n!=1
egen groupnum=group(tinc zztincgroupnum)
bys groupnum: egen taxyearmin=min(tax_year)
by groupnum: egen taxyearmax=max(tax_year)
drop zz* 
sort groupnum
save tempsoiubpgroupnum, replace

*SPREAD EACH groupnum TO A FULLY BALANCED SPINE 1996-2008;
keep tinc groupnum taxyearmin taxyearmax
duplicates drop groupnum, force
save temp, replace
clear
use temp, clear
gen tax_year=1996
save temp2, replace
forv t=1997/2008 {
  use temp, clear
  gen tax_year=`t'
  append using temp2
  save temp2, replace    
}
sort tinc tax_year
save temp2, replace

*OUTER JOIN TO RAW DATA, KEEPING UNMATCHED ROWS FROM temp2;
use ${dirdta}/rawsoiubp, clear
sort tinc tax_year
joinby tinc tax_year using temp2, unmatched(using)
drop _merge
tsset groupnum tax_year
sort groupnum tax_year
keep if inrange(tax_year,taxyearmin-2,taxyearmax)

*FILL IN MISSING penet AND inv VALUES AS NEEDED;
replace penet=F2.penetlag2 if tax_year==taxyearmin-2 & penet==.
replace penet=F1.penetlag if tax_year==taxyearmin-1 & penet==.
replace inv=F2.invlag2 if tax_year==taxyearmin-2 & inv==.
replace inv=F1.invlag if tax_year==taxyearmin-1 & inv==.

*RESHAPE WIDE;
gen t = tax_year - taxyearmin + 2
bys groupnum: egen T = max(t)
gen zzpenet0 = penet if t==0
gen zzpenetT = penet if t==T
bys groupnum: egen penet0 = mean(zzpenet0)
bys groupnum: egen penetT = mean(zzpenetT)
keep groupnum inv penet0 penetT T t
reshape wide inv, i(groupnum penet0 penetT T) j(t)

*COMPUTE groupnum-SPECIFIC DEPRECIATION RATE;
***Note: Adding a second row of data (equal to exactly half of the true data 
*** point) enables nl to run and find a root to this nonlinear equation.
sum groupnum
global groupnummax = r(max)
save tempcalcdeprate, replace
clear
gen groupnum=.
gen deprate=.
save tempdeprates, replace
forv g=1/$groupnummax {
  global g=`g'
  use tempcalcdeprate if groupnum==${g}, clear
  sum T
  global T = r(mean)
  gen y = penetT - inv${T}
  save temp, replace
  foreach var in y penet0 penetT inv0 inv1 inv2 inv3 inv4 inv5 inv6 inv7 inv8 inv9 inv10 inv11 inv12 {
    replace `var' = `var'/2
  }
  append using temp
  global deprate = .
  clear matrix
  if $T==12 {
    capture nl (y = {b}^(${T})*penet0 + {b}^(${T}-1)*inv1 + {b}^(${T}-2)*inv2 + {b}^(${T}-3)*inv3 + {b}^(${T}-4)*inv4 + {b}^(${T}-5)*inv5 + {b}^(${T}-6)*inv6 + {b}^(${T}-7)*inv7 + {b}^(${T}-8)*inv8 + {b}^(${T}-9)*inv9 + {b}^(${T}-10)*inv10 + {b}^(${T}-11)*inv11), initial(b .9) iterate(50)
  }
  else if $T==11 {
    capture nl (y = {b}^(${T})*penet0 + {b}^(${T}-1)*inv1 + {b}^(${T}-2)*inv2 + {b}^(${T}-3)*inv3 + {b}^(${T}-4)*inv4 + {b}^(${T}-5)*inv5 + {b}^(${T}-6)*inv6 + {b}^(${T}-7)*inv7 + {b}^(${T}-8)*inv8 + {b}^(${T}-9)*inv9 + {b}^(${T}-10)*inv10), initial(b .9) iterate(50)
  }
  else if $T==10 {
    capture nl (y = {b}^(${T})*penet0 + {b}^(${T}-1)*inv1 + {b}^(${T}-2)*inv2 + {b}^(${T}-3)*inv3 + {b}^(${T}-4)*inv4 + {b}^(${T}-5)*inv5 + {b}^(${T}-6)*inv6 + {b}^(${T}-7)*inv7 + {b}^(${T}-8)*inv8 + {b}^(${T}-9)*inv9), initial(b .9) iterate(50)
  }
  else if $T==9 {
    capture nl (y = {b}^(${T})*penet0 + {b}^(${T}-1)*inv1 + {b}^(${T}-2)*inv2 + {b}^(${T}-3)*inv3 + {b}^(${T}-4)*inv4 + {b}^(${T}-5)*inv5 + {b}^(${T}-6)*inv6 + {b}^(${T}-7)*inv7 + {b}^(${T}-8)*inv8), initial(b .9) iterate(50)
  }
  else if $T==8 {
    capture nl (y = {b}^(${T})*penet0 + {b}^(${T}-1)*inv1 + {b}^(${T}-2)*inv2 + {b}^(${T}-3)*inv3 + {b}^(${T}-4)*inv4 + {b}^(${T}-5)*inv5 + {b}^(${T}-6)*inv6 + {b}^(${T}-7)*inv7), initial(b .9) iterate(50)
  }
  else if $T==7 {
    capture nl (y = {b}^(${T})*penet0 + {b}^(${T}-1)*inv1 + {b}^(${T}-2)*inv2 + {b}^(${T}-3)*inv3 + {b}^(${T}-4)*inv4 + {b}^(${T}-5)*inv5 + {b}^(${T}-6)*inv6), initial(b .9) iterate(50)
  }
  else if $T==6 {
    capture nl (y = {b}^(${T})*penet0 + {b}^(${T}-1)*inv1 + {b}^(${T}-2)*inv2 + {b}^(${T}-3)*inv3 + {b}^(${T}-4)*inv4 + {b}^(${T}-5)*inv5), initial(b .9) iterate(50)
  }
  else if $T==5 {
    capture nl (y = {b}^(${T})*penet0 + {b}^(${T}-1)*inv1 + {b}^(${T}-2)*inv2 + {b}^(${T}-3)*inv3 + {b}^(${T}-4)*inv4), initial(b .9) iterate(50)
  }
  else if $T==4 {
    capture nl (y = {b}^(${T})*penet0 + {b}^(${T}-1)*inv1 + {b}^(${T}-2)*inv2 + {b}^(${T}-3)*inv3), initial(b .9) iterate(50)
  }
  else if $T==3 {
    capture nl (y = {b}^(${T})*penet0 + {b}^(${T}-1)*inv1 + {b}^(${T}-2)*inv2), initial(b .9) iterate(50)
  }
  else if $T==2 {
    capture nl (y = {b}^(${T})*penet0 + {b}^(${T}-1)*inv1), initial(b .9) iterate(50)
  }
  capture global deprate = 1 - _b[/b]
  use tempdeprates, clear
  drop if _n>=0
  set obs 1
  replace groupnum = ${g}
  replace deprate = ${deprate}
  append using tempdeprates
  save tempdeprates, replace
}  

*MERGE deprate TO MAIN DATA;
***Censor deprate to [0,.5] and impute mean deprate to missing deprate;
use tempdeprates, clear
sort groupnum
save tempdeprates, replace
merge 1:m groupnum using tempsoiubpgroupnum
drop _merge
replace deprate=.5 if deprate>.5 & deprate!=.
replace deprate=0 if deprate<0
sum deprate [w=${wgt}]
replace deprate=r(mean) if deprate==.

*CREATE penetsslag2to1 AND SAVE;
tsset groupnum tax_year
sort groupnum tax_year
gen penetsslag2 = penetlag2 if tax_year==taxyearmin
gen penetsslag = penetsslag2*(1-deprate) + invlag if tax_year==taxyearmin
gen penetss = penetsslag*(1-deprate) + inv if tax_year==taxyearmin
replace penetss = (L.penetss)*(1-deprate) + inv if penetss==.
replace penetsslag = L.penetss if penetsslag==.
replace penetsslag2 = L.penetsslag if penetsslag2==.
gen penetsslag2to1 = (penetsslag2+penetsslag)/2
save ${dirdta}/tempsoiubp, replace

*RUN REG;
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


************************;
*COLUMN 9;
************************;
global column = 9
global basevarroot = "penet"
use ${dirdta}/soiubp, clear
foreach root in lass_asslag2to1 liab_asslag2to1 {
	sum `root', detail
	replace `root'=r(p99) if `root'>r(p99) & `root'!=.		
	replace `root'=r(p1) if `root'<r(p1) & `root'!=.
	gen `root'_2 = `root'^2
	gen `root'_3 = `root'^3
	gen `root'_4 = `root'^4
}
save ${dirdta}/tempsoiubp, replace
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls lass_asslag2to1* liab_asslag2to1* i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
*SET NEW WEIGHT pswgt AND SAVE temp_yvarscaled
**SET PROPENSITY SCORE BY DOING WITHIN-YEAR REGRESSIONS
use temp_yvarscaled, clear
gen ps=.
forv t=1998/2008 {
  global t=`t'
  probit ddccorp ${controls} if tax_year==${t}
  predict zzps
  replace ps=zzps if tax_year==${t}
  drop zz*
}
**REWEIGHT
***Give C-corps weight equal to revlag2to1
***Give S-corps weight equal to revlag2to1 within each bin so that the 
*** total S-corp weight equals the total C-corp weight
gen psbin = floor(10*ps)
egen zzgroup = group(tax_year psbin)
gen zzrevlag2to1 = 2.71828^lnrevlag2to1
gen zzrevlag2to1_ddccorp1 = zzrevlag2to1 if ddccorp==1
gen zzrevlag2to1_ddccorp0 = zzrevlag2to1 if ddccorp==0
bys tax_year psbin: egen zzgroup_ddccorp1_totwgt = total(zzrevlag2to1_ddccorp1)
bys tax_year psbin: egen zzgroup_ddccorp0_totwgt = total(zzrevlag2to1_ddccorp0)
gen pswgt = zzrevlag2to1
replace pswgt = pswgt * (zzgroup_ddccorp1_totwgt/zzgroup_ddccorp0_totwgt) if ddccorp==0
***SET pswgt TO MISSING IF THERE'S NO BALANCE (ONLY ONE OBS)
replace pswgt = . if zzgroup_ddccorp1_totwgt==0 | zzgroup_ddccorp0_totwgt==0
drop zz*
save temp_yvarscaled, replace
*RUN REG;
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
global wgt = "pswgt"
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 10;
************************;
global column = 10
global basevarroot = "penet"
use ${dirdta}/soiubp, clear
save ${dirdta}/tempsoiubp, replace
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
global wgt = "revlag2to1"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg





******************************************************************;
                     ************************;
*(2.AT5) APPENDIX TABLE 5;
                     ************************;
******************************************************************;
global exhibit = "AT5"
global detrend = 0
global dothrough2004only = 0
global doyrbyyr = 0
global norm = 0
global cutvarnewdfl = 0
global dosizehetero = 0
global row = 0
global trimqtop = "p95"
global yvar = "invcumannual"
global basevarroot = "penet"
global data = "tempsoiubp"

forv radius=1/5 {
  global radius=`radius'
  global column=${radius}+1
  forv dopost2003=0/1 {
    global dopost2003 = `dopost2003'
	if $dopost2003==0 {
      use tinc tax_year using ${dirdta}/soiubp if inrange(tax_year,2002.5-${radius},2002.5), clear
	}
	else {
      use tinc tax_year using ${dirdta}/soiubp if inrange(tax_year,2002.5,2002.5+${radius}), clear
	}
    collapse (count) freq=tax_year, by(tinc)
    keep if freq==${radius}
	sort tinc
	merge 1:m tinc using ${dirdta}/soiubp
	keep if _merge==3
	drop _merge
	if $dopost2003==0 {
      keep if inrange(tax_year,2002.5-${radius},2002.5)
	}
	else {
      keep if inrange(tax_year,2002.5,2002.5+${radius})
	}
    bys tinc: egen invcumannual=total(inv)
	replace invcumannual=invcumannual/${radius}
	if $dopost2003==0 {
      keep if tax_year==2003-${radius}
	}
	else {
      keep if tax_year==2003
	}
    save tempsoiubp_dopost2003_${dopost2003}, replace
  }
  append using tempsoiubp_dopost2003_0
  sort tinc tax_year
  save ${dirdta}/tempsoiubp, replace
  do ${dirdo}/div_analysis_mainmacros
  global controls = "$controls i_ty*"
  do ${dirdo}/div_analysis_makeyvarscaled
  do ${dirdo}/div_analysis_ddreg
}




******************************************************************;
                     ************************;
*(2.AT6) APPENDIX TABLE 6;
**The section "PREP FOR COLUMNS 4-10" implements Auerbach-Hassett's (JPubE 1992) 
** cost-capital formulation. See the manuscript's Online Appendix D for full
** details. The code is fully general and can be used in other cost-of-capital
** work using firm-level data. See the subsection "PREP soiubp INVESTMENT SHARES 
** FOR EACH FIRM" for the part of the code that requires the firm-level data
** being used.
                     ************************;
******************************************************************;
global exhibit = "AT6"
global detrend = 0
global dothrough2004only = 0
global doyrbyyr = 0
global norm = 0
global cutvarnewdfl = 0
global dosizehetero = 0
global row = 0
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
global data = "tempsoiubp"


************************;
*COLUMN 2;
************************;
global column = 2
use ${dirdta}/soiubp, clear
save ${dirdta}/tempsoiubp, replace
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
use temp_yvarscaled if inrange(tax_year,1998,2001), clear
replace ddpost=(tax_year>=2001)
replace ddccorppost=ddccorp*ddpost
save temp_yvarscaled, replace
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 3;
************************;
global column = 3
use ${dirdta}/soiubp, clear
save ${dirdta}/tempsoiubp, replace
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
use temp_yvarscaled if inrange(tax_year,1998,2002) & tax_year!=2001, clear
replace ddpost=(tax_year>=2001)
replace ddccorppost=ddccorp*ddpost
save temp_yvarscaled, replace
do ${dirdo}/div_analysis_ddreg



************************;
*PREP FOR COLUMNS 4-10 (very long code);
************************;

************;
*COC INPUT PARAMETERS;
************;
global r = .025
global re = .1
global fifoshare = .3
global inflate = .03
global tcgfactor = .25
global debtshare = .4
global numcocleads = 100
global numcocleadsplusone = ${numcocleads}+1
**General: ${classlifelength} must be different from the GDS lives (3,5,7,10,15,20,25,50)
** to prevent run error below
global classlifelength = 9
**General: ${s179length} and ${listedproplength} must be a GDS assetlife (i.e. in
** {3,5,7,10,15,20,25,27.5,39,40,50}) to prevent run error below
global s179length = 5
global listedproplength = 5
global w_equip = .583
global w_struct = .95
global maxequipassetlife = 9
global kssalpha = .5
global ahcocmean = .21
global ahequipcoeff = -.253
global ahstructcoeff = -.09

************;
*COMPUTE coc BY ddccorp-taxyear-assetlife;
************;

******;
*CREATE LONG DATASET OF EXPECTATIONS, INDEXED BY tax_year-yrlead (yrlead in [0,60]);
******;
clear
gen tax_year=.
gen yrlead=.
gen exptcorp=.
gen exptord=.
gen exptcg=.
gen expbonus=.
save temptaxratepath1, replace
forv yrlead0=1996/2008 {
  global yrlead0 = `yrlead0'
  insheet using ${dirrawdata}/taxrates_all_19962012fedplusstateavg.csv, comma clear
  drop tdiv
  gen tax_year=${yrlead0}
  *RENAME VARS AND SET PAST YEARS TO MISSING, JUST TO MAKE SURE CODE IS ;
  * CORRECT AND DOESN'T USE THEM;
  foreach var in tcorp tord tcg bonus {
    replace `var'=. if year<tax_year
    rename `var' exp`var'
  }
  
  *OVERWRITE PERFECT FORESIGHT FOR SPECIFIC CASES;
  **IF YEAR ZERO IS <=2000, THEN PROJECT YEAR 2000 FORWARD FOREVER;
  if $yrlead0<=2000 {
    foreach var in exptcorp exptord exptcg expbonus {
      sum `var' if year==2000
      replace `var'=r(mean) if year>2000
    }
  }
  **IF YEAR ZERO IS 2001-2002, THEN PROJECT FORWARD AS LEGISLATED IN EGTRRA 2001;
  ** IN 2001, BUT ALLOW PERFECT FORESIGHT ON ITS EVENTUAL EXPIRATION;
  ** Note: the lines in the if statement handle both the oecd and non-oecd cases;
  else if $yrlead0<=2002 {
    quietly sum exptord if year==2002
    replace exptord=r(mean) if year==2003
    replace exptord=r(mean)-(.386-.376) if inrange(year,2004,2005)
    replace exptord=r(mean)-(.386-.35) if inrange(year,2006,2012)
    quietly sum exptcg if year==2002
    replace exptcg=r(mean) if inrange(year,2003,2012)
    replace expbonus=0 if year>=2003
  }
  *IF YEAR ZERO IS 2003-2007, DID NOT SEE THE GREAT RECESSION AND ITS BONUS COMING;
  else if $yrlead0<=2007 {
    replace expbonus=0 if year>=2008
  }
  *IF YEAR ZERO IS 2008, ONLY SAW BONUS COMING AS FAR AS LEGISTLATED IN THE;
  * ECONOMIC STIMULUS ACT OF 2008, FOR CONSISTENCY WITH 2001;
  else if $yrlead0==2008 {
    replace expbonus=0 if year>=2009
  }
  
  *ADD YEARS THROUGH yrleadmax AND EXTEND TERMINAL ACTUAL YEAR'S VALUES;
  sum year
  global yearmax=r(max)
  global yearmaxplusone=${yearmax}+1
  global yrleadmax=${yrlead0}+50+${numcocleadsplusone}
  save temptaxratepath2, replace
  forv yrlead=$yearmaxplusone/$yrleadmax {
    use temptaxratepath2 if year==${yearmax}, clear
    replace year=`yrlead'
    append using temptaxratepath2
    save temptaxratepath2, replace
  }
  sort year
  list
  gen yrlead=year-tax_year
  drop if yrlead<0
  drop year
  append using temptaxratepath1
  save temptaxratepath1, replace
}
*INDEX BY ddccorp-tax_year-t WITH NEW TAX RATE tbiz (ON ANNUAL BUSINESS INCOME);
use temptaxratepath1, clear
gen ddccorp=1
gen exptbiz=exptcorp
append using temptaxratepath1
replace ddccorp=0 if ddccorp==.
replace exptbiz=exptord if ddccorp==0
drop exptcorp
order ddccorp tax_year yrlead exptbiz exptord exptcg 
save temptaxratepath, replace


******;
*COMPUTE TAX DEPRECIATION DEDUCTIONS BY YEAR;
******;
*ENLARGE THE DATASET BY ADDING yrpurchasedlead-assetlife;
use temptaxratepath, clear
drop if _n>=0
gen yrpurchasedlead=.
gen assetlife=.
save tempdepstream1, replace
forv yrpurchasedlead=0/$numcocleadsplusone {
  foreach assetlife in 3 5 7 ${classlifelength} 10 12 15 20 25 27.5 39 40 50 {
    use temptaxratepath, clear
    gen yrpurchasedlead=`yrpurchasedlead'
    gen assetlife=`assetlife'
    append using tempdepstream1
    save tempdepstream1, replace
  }
}
order ddccorp tax_year yrpurchasedlead assetlife yrlead
save tempdepstream1, replace

*SET EXPECTED STREAM OF DEPRECIATION DEDUCTIONS FOR EACH ;
* tax_year-yrpurchasedlead-assetlife-yrlead, using the assumptions in ;
* CHH NTJ 2002 pp.459-460 and in CHH code (which switches from double-;
* declining balance method to straight-line method when profitable;
use tempdepstream1, clear
gen zzyrsincepurchase = yrlead-yrpurchasedlead
gen zzdepdbm=.
gen zzdepsl=.
gen dep=0
gen zzdepaccum=0

**SET dbm WHICH EQUALS THE DECLINING BALANCE METHOD (DOUBLE, 150%, OR 
** STRAIGHT-LINE). GDS {3,5,7,10} IS DOUBLE. GDS {15, 20} is 150%. ;
** ALL ELSE IS STRAIGHT-LINE. SEE HOUSE-SHAPIRO TABLE A1 NOTES. FORM 
** 4562 SHOWS THAT 25-YEAR PROPERTY IS STRAIGHT-LINE.
gen dbm = 1
replace dbm = 1.5 if assetlife==15 | assetlife==20
replace dbm = 2 if inlist(assetlife,3,5,7,10)

**FOR ADS ASSETLIVES AND GDS ASSETLIVES >20, SET expbonus=0 BECAUSE 
** GDS LIVES >20 ARE NOT ELIGIBLE FOR BONUS, AND SAME FOR PROPERTY 
** REQUIRED TO BE DEPRECIATED BY ADS (AND ADS IS SLOWER THAN
** GDS SO FIRMS SHOULD TYPICALLY USE ADS ONLY WHEN THE PROPERTY IS 
** REQUIRED TO BE DEPRECIATED BY ADS, e.g. FOREIGN-INSTALLED MACHINES).
replace expbonus=0 if assetlife>20 | inlist(assetlife,${classlifelength},12,40)

**ASSIGN FIRST-YEAR DEDUCTION IF THIS ROW CORRESPONDS TO THE YEAR OF PURCHASE
replace zzdepdbm = expbonus + (1-expbonus)*(.5)*dbm/assetlife if zzyrsincepurchase==0
replace zzdepsl = expbonus + (1-expbonus)*(.5)*1/assetlife if zzyrsincepurchase==0
replace dep = max(zzdepdbm,zzdepsl) if zzyrsincepurchase==0 
replace zzdepaccum = dep if zzyrsincepurchase==0 
list assetlife yrlead zz* dep if _n<20

**DO REMAINING YEARS IN LOOP
global yrsincepurchasemax = ${numcocleadsplusone} + 50 + 1
forv yrsincepurchase=1/$yrsincepurchasemax {
  global yrsincepurchase=`yrsincepurchase'
  *ASSIGN SUBSEQUENT YEAR DEDUCTION IF THIS ROW CORRESPONDS TO A YEAR AFTER
  * AND NOT YET THE END OF THE ASSET LIFE
  replace zzdepdbm = (1-zzdepaccum[_n-1])*dbm/assetlife if ${yrsincepurchase}==zzyrsincepurchase & ${yrsincepurchase}<assetlife & dep[_n-1]!=zzdepsl
  replace zzdepsl = (1-zzdepaccum[_n-1])/(assetlife-${yrsincepurchase}+.5) if ${yrsincepurchase}==zzyrsincepurchase & ${yrsincepurchase}<assetlife
  replace dep = max(zzdepdbm,zzdepsl) if ${yrsincepurchase}==zzyrsincepurchase & ${yrsincepurchase}<assetlife
  *ASSIGN FINAL YEAR OR POST-FINAL-YEAR DEDUCTION IF ROW CORRESONDS TO END OR 
  * AFTER END OF ASSETLIFE (DEPRECIATES ALL REMAINING BALANCE IN THE LAST YEAR 
  ** AND SETS DEPRECIATION TO ZERO AFTERWARD)
  replace dep = 1-zzdepaccum[_n-1] if ${yrsincepurchase}==zzyrsincepurchase & ${yrsincepurchase}>=assetlife
  *INCREMENT zzdepaccum
  replace zzdepaccum = zzdepaccum[_n-1] + dep if ${yrsincepurchase}==zzyrsincepurchase
}
drop zz*
save tempdepstream2, replace

*VALIDATE BY REPRODUCING CHH TABLE 1 COL 1-6 AND IRS PUBLICATION 
* 946 TABLE A-1
use tempdepstream2, clear
list tax_year yrpurchased assetlife yrlead dep if tax_year==2000 & yrpurchasedlead==0 & assetlife==7 & ddccorp==1 & yrlead<10
list tax_year yrpurchased assetlife yrlead dep if tax_year==2002 & yrpurchasedlead==0 & assetlife==7 & ddccorp==1 & yrlead<10
list tax_year yrpurchased assetlife yrlead dep if tax_year==2000 & yrpurchasedlead==0 & assetlife==5 & ddccorp==1 & yrlead<10
list tax_year yrpurchased assetlife yrlead dep if tax_year==2002 & yrpurchasedlead==0 & assetlife==5 & ddccorp==1 & yrlead<10
list tax_year yrpurchased assetlife yrlead dep if tax_year==2000 & yrpurchasedlead==0 & assetlife==3 & ddccorp==1 & yrlead<10
list tax_year yrpurchased assetlife yrlead dep if tax_year==2002 & yrpurchasedlead==0 & assetlife==3 & ddccorp==1 & yrlead<10

******;
*FIT ECONOMIC DEPRECIATION RATES BY assetlife;
******;
*USE HOUSE-SHAPIRO (AER 2008) TABLE A2 TO COMPUTE ${decon_dtax_ratio} (the 
* average ratio of economic depreciation to tax depreciation) TO USE BELOW WITH 
* dbm AND assetlife TO ESTIMATE decon
**ANSWER: ${decon_dtax_ratio}=0.47, so decon = 0.47*[dbm/assetlife] 
** (the constant is nearly zero when allowed);
**NOTE: ${decon_dtax_ratio}=0.47 is similar to Auerbach's (IER 1989) assumption
** of 0.5 (his Table 1).;
insheet using ${dirrawdata}/houseshapiro_tablea2_decon_rates.csv, comma clear
reg decon dtax
reg decon dtax, nocons
global decon_dtax_ratio = _b[dtax]
log on oneoffstats
disp "MANUSCRIPT ONLY: House-Shapiro best-fit economic depreciation rate as share of tax depreciation rate"
disp ${decon_dtax_ratio}
log off oneoffstats

*ADD decon AND SAVE;
use tempdepstream2, clear
gen decon = ${decon_dtax_ratio}*(dbm/assetlife)
drop dbm
sort ddccorp tax_year assetlife yrpurchased yrlead
save tempdepstream3, replace


******;
*GET deptaxnpv AND coc BY MULTIPLYING NOMINAL DEPRECIATION DEDUCTIONS ;
* BY THE EXPECTED BUSINESS TAX RATE IN THAT YEAR, DISCOUNTING, AND WEIGHTING;
******;
*FOLLOW CHH NTJ BY USING AN INVENTORY-ADJUSTED TAX RATE
* EQUAL TO exptbiz*(1+${fifoshare}*${inflate}) RATHER THAN JUST exptbiz
use tempdepstream3, clear
gen zzdeptax = dep*exptbiz*(1+${fifoshare}*${inflate})

*DEFINE DISCOUNT RATE IN YEAR OF PURCHASE AS IN CHH NTJ;
gen zzrr = ${debtshare}*((${r}+${inflate})*(1-exptbiz*(1+${fifoshare}*${inflate}))/(1-exptord)-${inflate}) + (1-${debtshare})*((${re}+${inflate}*exptcg*${tcgfactor})/(1-exptcg*${tcgfactor})) if yrlead==yrpurchasedlead
bys ddccorp tax_year assetlife yrpurchasedlead: egen rr = mean(zzrr)

*DISCOUNT EACH ROW'S zzdeptax BACK TO YEAR OF PURCHASE AS IN CHH NTJ CODE ;
* (i.e. compute gamma);
gen zzyrsincepurchase = yrlead-yrpurchasedlead
gen deptaxnpv = zzdeptax/(1+rr+${inflate})^zzyrsincepurchase

*DEFINE exptbiz IN YEAR OF PURCHASE;
gen exptbizyrpurchasedlead = exptbiz if yrlead==yrpurchasedlead

*SUM deptaxnpv WITHIN EACH ddccorp-tax_year-assetlife-yrpurchasedlead ;
* AND KEEP rr AND exptbizyrpurchasedlead FOR COMUTATION OF coc;
collapse (sum) deptaxnpv (mean) rr decon exptbizyrpurchasedlead, by(ddccorp tax_year assetlife yrpurchasedlead)

*COMPUTE coc;
**Note: coc is correctly missing for the last row within every 
** ddccorp-tax_year-assetlife, since there is no valid [_n+1] in the last row;
sort ddccorp tax_year assetlife yrpurchasedlead
gen coc = (rr+decon+(deptaxnpv[_n+1]-deptaxnpv)/(1-deptaxnpv))*(1-deptaxnpv)/(1-exptbizyrpurchasedlead) if assetlife==assetlife[_n+1]
drop if coc==.

*SET exptbizss AND deptaxnpvss AND cocss AND SAVE ("ss" denotes "steady-state");
foreach var in exptbizyrpurchasedlead deptaxnpv coc rr {
  gen zz`var'ss = `var' if yrpurchasedlead==${numcocleads}
  bys ddccorp tax_year assetlife: egen `var'ss = mean(zz`var'ss)
}
rename exptbizyrpurchasedleadss exptbizss
save depstream, replace

*VALIDATE BY NEARLY REPRODUCING THE COST OF CAPITAL VALUES IN CHH TABLE 2
**Note: The values do not match exactly due to some combination of this paper 
** using state-plus-federal tax rates instead of just federal tax rates, using 
** asset-life-specific economic depreciation rates (not explicitly documented 
** in CHH), and using different discount rates (CHH use a 7.5% discount rate in 
** their Table 2, whereas I use CHH's microfounded discount rate used in other  
** CHH tables).  Note also that unlike CHH, my 2004 ("Transition Year") value 
** reflects the 2003 tax reform's expansion of accelerated depreciation allowances.
use depstream, clear
list tax_year assetlife coc if yrpurchasedlead==0 & ddccorp==1 & inrange(assetlife,3,7) & inlist(tax_year,2000,2002,2004)

*USE ${w} TO TAKE WEIGHTED AVERAGE OF coc ACROSS yrpurchasedlead;
use depstream, clear
gen wgt = ${w_equip}^yrpurchasedlead if assetlife<=${maxequipassetlife}
replace wgt = ${w_struct}^yrpurchasedlead if assetlife>${maxequipassetlife}

*COLLAPSE SIMPLY BY USING [w=wgt] SINCE THE WEIGHTS SUM TO ONE BY ;
* CONSTRUCTION, AS IN AUERBACH-HASSETT;
gen tbiz = exptbizyrpurchasedlead if yrpurchasedlead==0
replace deptaxnpv=. if yrpurchasedlead!=0
collapse (mean) coc exptbizss deptaxnpvss cocss rr rrss decon deptaxnpv tbiz [w=wgt], by(ddccorp tax_year assetlife)
sort ddccorp assetlife tax_year 
keep if tax_year>=1998
sort ddccorp tax_year assetlife
save cocbyddccorptaxyearassetlife, replace


************;
*PREP soiubp INVESTMENT SHARES FOR EACH FIRM;
**For each tinc-tax_year-assetlife, the invshare equals total investment ;
** by that tinc in that assetlife category over the last two years, divided ;
** by that tinc's total investment over the last two years;
**If implementing this code with another dataset of firm-level data, replace 
** this code with analogous code that computes the share of each firm's 
** investment that is made in each asset life bin.
************;
*LOAD DATA AND ALLOCATE BONUS PRO RATA TO MACRS CATEGORIES w/ <=20 ASSET LIVES;
use tinc tax_year ddccorp invmacrsgds* invmacrsads* invbonus* invs179* invlist* using ${dirdta}/soiubp, clear
foreach suffix in lag lag2 {
  replace invbonus`suffix'=0 if invbonus`suffix'==.
  gen zzinvmacrstotal_3_20`suffix' = 0
  foreach assetlife in 03 05 07 10 15 20 {
    replace zzinvmacrstotal_3_20`suffix' = zzinvmacrstotal_3_20`suffix' + invmacrsgds`assetlife'yr`suffix'
  }
  foreach assetlife in 03 05 07 10 15 20 {
    replace invmacrsgds`assetlife'yr`suffix' = invmacrsgds`assetlife'yr`suffix' + (invmacrsgds`assetlife'yr`suffix'/zzinvmacrstotal_3_20`suffix')*invbonus`suffix' if zzinvmacrstotal_3_20`suffix'>0
  }
}

*SET NEW inv VARS FOR MACRS AND ADS INVESTMENT;
foreach assetlife in 03 05 07 10 15 20 25 50 {
  gen inv`assetlife' = invmacrsgds`assetlife'yrlag + invmacrsgds`assetlife'yrlag2
}
foreach assetlife in 12 40 {
  gen inv`assetlife' = invmacrsads`assetlife'yrlag + invmacrsads`assetlife'yrlag2
}

*ALLOCATE SPECIAL INVESTMENT CATEGORIES;
gen inv28 = invmacrsgdsreslag + invmacrsgdsreslag2
gen inv39 = invmacrsgdsnonreslag + invmacrsgdsnonreslag2
gen inv${classlifelength} = invmacrsadsclasslag + invmacrsadsclasslag2
replace inv0${s179length} = inv0${s179length} + invs179lag + invs179lag2
replace inv0${listedproplength} = inv0${listedproplength} + invlistlag + invlistlag2

*RESHAPE LONG;
keep tinc tax_year ddccorp inv03 inv05 inv07 inv10 inv15 inv20 inv25 inv12 inv40 inv50 inv28 inv39 inv${classlifelength}
foreach suffix in 3 5 7 {
  rename inv0`suffix' inv`suffix'
}
reshape long inv, i(tinc tax_year ddccorp) j(assetlife)
replace assetlife=27.5 if assetlife==28

*SET invshare FOR EACH tinc-tax_year-assetlife;
bys tinc tax_year: egen zzinvtotal=total(inv)
gen invshare = inv/zzinvtotal

*FOR THE 4% OF ROWS WITH NO LAGGED INVESTMENT, SET invshare VALUES EQUAL TO THE ;
* MEAN VALUES FOR THE ddccorp-tax_year;
bys ddccorp tax_year assetlife: egen zzinvsharemean=mean(invshare)
replace invshare=zzinvsharemean if invshare==.

*DROP UNNECESSARY VARS AND SAVE;
drop zz* inv
sort ddccorp tax_year assetlife
save soiubpinvshares, replace


************;
*CREATE cocfull;
************;
*SET ${mu1} AS WEIGHTED AVERAGE OF THE mu1 IMPLIED BY ${kssalpha} AND ;
* AUERBACH-HASSETT COC COEFFS, AS DETAILED ON p.153 OF AH. THE WEIGHTED ;
* AVERAGE IS ACROSS THE TWO mu1's IMPLIED BY THE AH EQUIPMENT AND STRUCTURES ;
* REGRESSIONS, WEIGHTED BY THE EQUIPMENT SHARE OF INVESTMENT IN THIS PAPER'S DATA.;
use soiubpinvshares, clear
gen equip = (assetlife<=${maxequipassetlife})
collapse (sum) invshare, by(equip tinc tax_year)
sum invshare if equip==1
global equipinvshare = r(mean)
global mu1 = 1-${kssalpha}*${ahcocmean}*(-1)*(${equipinvshare}*${ahequipcoeff}+(1-${equipinvshare})*${ahstructcoeff})

*IN AUERBACH-HASSETT MODEL FOR A LONG-LIVED FIRM, GENERATE PREDICTED ;
* TIME-PATH OF CAPITAL STOCKS AND SET klag_kss;
use cocbyddccorptaxyearassetlife, clear
sort ddccorp assetlife tax_year
*COMPUTE kss IN ALL YEARS
gen kss = ((1-${kssalpha})*(1-exptbizss*(1+${fifoshare}*${inflate}))/((rrss+decon)*(1-deptaxnpvss)))^(1/${kssalpha})
*COMPUTE inv AND kssfactor IN 1998 FOR EACH ddccorp-assetlife, ASSUMING WAS IN ;
* STEADY STATE IN 1998 (inv=deconall AND kssfactor=1 HERE)
gen klag_kss = 1 if tax_year==1998
gen inv_klag = decon + (1-${mu1})/${kssalpha}*(1-(klag_kss^${kssalpha})*(coc/cocss)) if tax_year==1998
*COMPUTE kend (END-OF-YEAR CAPITAL STOCK) IN 1998
gen kend = kss*(1 + inv_klag - decon) if tax_year==1998
*ITERATE THROUGH REMAINING YEARS
forv t=1999/2008 {
  replace klag_kss = kend[_n-1]/kss if tax_year==`t'
  replace inv_klag = decon + (1-${mu1})/${kssalpha}*(1-klag_kss^${kssalpha}*(coc/cocss)) if tax_year==`t'
  replace kend = kend[_n-1]*(1 + inv_klag - decon) if tax_year==`t'
}

*SET cocallfull AND cocallfull2 AND SAVE ;
gen cocfull = (coc/cocss)*klag_kss^${kssalpha}
drop kss klag_kss inv_klag kend
sort ddccorp tax_year assetlife
save cocbyddccorptaxyearassetlife2, replace


************;
*MERGE coc ONTO EACH FIRM'S VECTOR OF INVESTMENT SHARES BY ;
* dccorp-tax_year-coc AND TAKE WEIGHTED AVERAGE TO COMPUTE EACH ;
* FIRM'S COST OF CAPITAL;
************;
*MERGE TO soiubpinvshares AND COLLAPSE;
use soiubpinvshares, clear
merge m:1 ddccorp tax_year assetlife using cocbyddccorptaxyearassetlife2
collapse (mean) coc* exp* dep* decon* [w=invshare], by(ddccorp tinc tax_year)

*KEEP CERTAIN VARS AND SET POWERS;
drop exp* dep* cocss*
forv power=2/4 {
  gen coc_`power'=coc^`power'
  gen cocfull_`power'=cocfull^`power'
  gen decon_`power'=decon^`power'
}

*MERGE TO soiubp AND SAVE;
sort tinc tax_year
save tempcoc, replace
use ${dirdta}/soiubp, clear
sort tinc tax_year
merge 1:1 tinc tax_year using tempcoc
drop _merge
sort tinc tax_year
save ${dirdta}/tempsoiubp, replace

*MERGE ON invshare's, SET POWERS, AND SAVE;
use tinc tax_year assetlife invshare using soiubpinvshares, clear
replace assetlife=28 if assetlife==27.5
reshape wide invshare, i(tinc tax_year) j(assetlife)
gen invbonuseligshare = invshare3 + invshare5 + invshare7 + invshare10 + invshare15 + invshare20
gen invbonuseliglife = (3*invshare3 + 5*invshare5 + 7*invshare7 + 10*invshare10 + 15*invshare15 + 20*invshare20)/invbonuseligshare
replace invbonuseliglife=0 if invbonuseliglife==.
foreach assetlife in 3 5 7 10 12 15 20 25 28 39 40 50 $classlifelength {
  forv power=2/4 {
    gen invshare_`power'_`assetlife' = invshare`assetlife'^`power'
  }
  rename invshare`assetlife' invshare__`assetlife'
}
foreach var in invbonuseligshare invbonuseliglife {
  forv power=2/4 {
    gen `var'_`power' = `var'^`power'
  }
}
rename invbonuseligshare invbonuseligshare_1
rename invbonuseliglife invbonuseliglife_1
sort tinc tax_year
merge 1:1 tinc tax_year using ${dirdta}/tempsoiubp
drop _merge
save ${dirdta}/tempsoiubp, replace
save ${dirdta}/tempsoiubp_${exhibit}, replace
log on oneoffstats
disp "MANUSCRIPT ONLY: mean cost of capital (coc) in the sample"
sum coc [w=dfl_main]
disp "MANUSCRIPT ONLY: mean values of eligible bonus share and mean bonus eligible life"
tab ddccorp [w=dfl_main], sum(invbonuseligshare_1)
tab ddccorp [w=dfl_main], sum(invbonuseliglife_1)
log off oneoffstats



************************;
*COLUMN 4;
************************;
global column = 4
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty* invbonuseligshare* invbonuseliglife*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty* c.invbonuseligshare*##c.invbonuseliglife*##i.tax_year"
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 5;
************************;
global column = 5
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty* decon"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 6;
************************;
global column = 6
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty* coc"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 7;
************************;
global column = 7
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty* decon coc"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 8;
************************;
global column = 8
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty* decon coc coc_*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 9;
************************;
global column = 9
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty* decon cocfull"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

************************;
*COLUMN 10;
************************;
global column = 10
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty* decon cocfull cocfull_*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg




******************************************************************;
                     ************************;
*(2.AT7) APPENDIX TABLE 7;
                     ************************;
******************************************************************;
global exhibit = "AT7"
global detrend = 0
global dothrough2004only = 0
global doyrbyyr = 0
global norm = 0
global cutvarnewdfl = 0
global dosizehetero = 0
global row = 0


global column = 1
global data = "soiubp_public"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 2
global data = "soiubp_public"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 3
global data = "soibp_public"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 4
global data = "soiubp_public"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 5
global data = "soiubp_public"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 6
global data = "soibp_public"
global trimqtop = "p99"
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 7
global data = "soiubp_public"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 8
global data = "soiubp_public"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 9
global data = "soibp_public"
global trimqtop = "p95"
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg


global column = 10
global data = "soiubp_public"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 11
global data = "soiubp_public"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg

global column = 12
global data = "soibp_public"
global trimqtop = "p95"
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg





******************************************************************;
                     ************************;
*(2.AT8) MAIN TABLE 4 / APPENDIX TABLE 8;
                     ************************;
******************************************************************;
global exhibit = "AT8"
global dothrough2004only = 0
global doyrbyyr = 1
global norm = 1
global cutvarnewdfl = 0
global dosizehetero = 0
global row = 0
global yvar = "payout"
global basevarroot = "rev"
global trimqtop = "p95"


global column = 1
global detrend = 0
global data = "soiubp"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg
do ${dirdo}/div_analysis_ddregyrbyyr

global column = 2
global detrend = 0
global data = "soiubp"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg
do ${dirdo}/div_analysis_ddregyrbyyr

global column = 3
global detrend = 0
global data = "soibp"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg
do ${dirdo}/div_analysis_ddregyrbyyr


global column = 4
global detrend = 1
global data = "soiubp"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg
do ${dirdo}/div_analysis_ddregyrbyyr

global column = 5
global detrend = 1
global data = "soiubp"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg
do ${dirdo}/div_analysis_ddregyrbyyr

global column = 6
global detrend = 1
global data = "soibp"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg
do ${dirdo}/div_analysis_ddregyrbyyr




******************************************************************;
                     ************************;
*(2.AT9) APPENDIX TABLE 9;
                     ************************;
******************************************************************;
global exhibit = "AT9"
global dothrough2004only = 0
global doyrbyyr = 1
global norm = 1
global cutvarnewdfl = 0
global dosizehetero = 0
global row = 0
global yvar = "div"
global basevarroot = "rev"
global trimqtop = "p95"


global column = 1
global detrend = 0
global data = "soiubp"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg
do ${dirdo}/div_analysis_ddregyrbyyr

global column = 2
global detrend = 0
global data = "soiubp"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg
do ${dirdo}/div_analysis_ddregyrbyyr

global column = 3
global detrend = 0
global data = "soibp"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg
do ${dirdo}/div_analysis_ddregyrbyyr


global column = 4
global detrend = 1
global data = "soiubp"
do ${dirdo}/div_analysis_mainmacros
global controls = "i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg
do ${dirdo}/div_analysis_ddregyrbyyr

global column = 5
global detrend = 1
global data = "soiubp"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg
do ${dirdo}/div_analysis_ddregyrbyyr

global column = 6
global detrend = 1
global data = "soibp"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
do ${dirdo}/div_analysis_makeyvarscaled
do ${dirdo}/div_analysis_ddreg
do ${dirdo}/div_analysis_ddregyrbyyr




******************************************************************;
                     ************************;
*(2.FINAL) OUTSHEET REGRESSION OUTPUT TO CSV'S;
                     ************************;
******************************************************************;
global pc_tdiv = ((1-.208)-(1-.447))/(1-.447)

use divout_coeffs, clear
egen lookupkey = concat(exhibit column row), punct("_")
sort lookupkey
order lookupkey
gen t=dd/dd_se
gen e = (dd/byvar1premean)/$pc_tdiv if norm==0
replace e = dd/$pc_tdiv if norm==1
gen e_top = ((dd+1.96*dd_se)/byvar1premean)/$pc_tdiv if norm==0
replace e_top = (dd+1.96*dd_se)/$pc_tdiv if norm==1
gen e_bot = ((dd-1.96*dd_se)/byvar1premean)/$pc_tdiv if norm==0
replace e_bot = (dd-1.96*dd_se)/$pc_tdiv if norm==1
outsheet using ${dirout}/divout_coeffs.csv, comma noquote replace

use divout_coeffs_yrbyyr, clear
egen lookupkey = concat(exhibit column), punct("_")
sort lookupkey
order lookupkey
gen t2003=dd2003/dd2003_se
gen e2003 = (dd2003/byvar1premean)/$pc_tdiv if norm==0
replace e2003 = dd2003/$pc_tdiv if norm==1
gen e2003_top = ((dd2003+1.96*dd2003_se)/byvar1premean)/$pc_tdiv if norm==0
replace e2003_top = (dd2003+1.96*dd2003_se)/$pc_tdiv if norm==1
gen e2003_bot = ((dd2003-1.96*dd2003_se)/byvar1premean)/$pc_tdiv if norm==0
replace e2003_bot = (dd2003-1.96*dd2003_se)/$pc_tdiv if norm==1
outsheet using ${dirout}/divout_coeffs_yrbyyr.csv, comma noquote replace

use divout_tab1adata, clear
egen lookupkey = concat(var byvar), punct("_")
sort lookupkey
order lookupkey
format mean p50 p10 p90 %15.0g
outsheet using ${dirout}/divout_tab1adata.csv, comma noquote replace





*************************************************************************;
*************************************************************************;
*(3) GENERATE FIGURES;
*************************************************************************;
*************************************************************************;

******************************************************************;
                     ************************;
*(3.1) MAIN FIGURE 1;
                     ************************;
******************************************************************;
*FIGURE 1a
use dfl_main ddccorp_byvar nc2dig using $dirdta/soiubp if dfl_main>0, clear
gen nc1dig = floor(nc2dig/10)
collapse (count) freq=dfl_main, by(nc1dig ddccorp_byvar)
rename ddccorp_byvar byvar
bys byvar: egen freqtotal=sum(freq)
gen frac = freq/freqtotal
keep frac nc1dig byvar
reshape wide frac, i(nc1dig) j(byvar)
outsheet using ${dirout}/divout_fig1adata.csv, comma replace

*FIGURE 1b
use ddccorp_byvar revlag2to1 dfl_main using $dirdta/soiubp if dfl_main>0, clear
gen bin=1
replace bin=2 if revlag2to1>10000000
replace bin=3 if revlag2to1>50000000
replace bin=4 if revlag2to1>100000000
collapse (count) freq=revlag2to1, by(ddccorp_byvar bin)
bys ddccorp_byvar: egen freqtotal=sum(freq)
gen frac = freq/freqtotal
rename ddccorp_byvar byvar
keep frac bin byvar
reshape wide frac, i(bin) j(byvar)
outsheet using ${dirout}/divout_fig1bdata.csv, comma replace



******************************************************************;
                     ************************;
*(3.2) MAIN FIGURE 2;
                     ************************;
******************************************************************;
global dothrough2004only = 0
global doyrbyyr = 0
global cutvarnewdfl = 0
global dosizehetero = 0
global data = "soiubp"
global trimqtop = "p95"

*FIGURE 2a
global detrend = 0
global norm = 0
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
global ddvarsorig = "$ddvars"
global wgtorig = "$wgt"
do ${dirdo}/div_analysis_makeyvarscaled_graph
do ${dirdo}/div_analysis_graph
use tempgraphdata, clear
twoway scatter resid tax_year if byvar==1, ///
	graphregion(fcolor(white)) title("$var") xtitle("Year") ///
	c(l) color(navy) xlabel(1998(1)2008) ///
	xline(2002.5, lp(solid) lc(black)) ylabel(.20(.04).32) ///
	|| scatter resid tax_year if byvar==0, c(l) color(cranberry)
graph export ${dirout}/G_fig2a_inv.eps, replace
*MANUSCRIPT ONLY: list 2002 data point for text
log on oneoffstats
disp "MANUSCRIPT ONLY: 2002 C-corp data point IN Fig 2a"
list if tax_year==2002 & byvar==1
log off oneoffstats

*FIGURE 2b
global detrend = 0
global norm = 0
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
global ddvarsorig = "$ddvars"
global wgtorig = "$wgt"
do ${dirdo}/div_analysis_makeyvarscaled_graph
do ${dirdo}/div_analysis_graph
use tempgraphdata, clear
twoway scatter resid tax_year if byvar==1, ///
	graphregion(fcolor(white)) title("$var") xtitle("Year") ///
	c(l) color(navy) xlabel(1998(1)2008) ///
	xline(2002.5, lp(solid) lc(black)) ylabel(-.01(.005).1) ///
	|| scatter resid tax_year if byvar==0, c(l) color(cranberry)
graph export ${dirout}/G_fig2b_netinv.eps, replace

*FIGURE 2c
global detrend = 0
global norm = 0
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
global ddvarsorig = "$ddvars"
global wgtorig = "$wgt"
do ${dirdo}/div_analysis_makeyvarscaled_graph
do ${dirdo}/div_analysis_graph
use tempgraphdata, clear
twoway scatter resid tax_year if byvar==1, ///
	graphregion(fcolor(white)) title("$var") xtitle("Year") ///
	c(l) color(navy) xlabel(1998(1)2008) ///
	xline(2002.5, lp(solid) lc(black)) ///
	|| scatter resid tax_year if byvar==0, c(l) color(cranberry)
graph export ${dirout}/G_fig2c_comp.eps, replace

*FIGURE 2d
global detrend = 1
global norm = 1
global yvar = "payout"
global basevarroot = "rev"
do ${dirdo}/div_analysis_mainmacros
global controls = "$controls i_ty*"
global ddvarsorig = "$ddvars"
global wgtorig = "$wgt"
do ${dirdo}/div_analysis_makeyvarscaled_graph
do ${dirdo}/div_analysis_graph
use tempgraphdata, clear
twoway scatter resid tax_year if byvar==1, ///
	graphregion(fcolor(white)) title("$var") xtitle("Year") ///
	c(l) color(navy) xlabel(1998(1)2008) ///
	xline(2002.5, lp(solid) lc(black)) ylabel(.625(.125)2.25) ///
	|| scatter resid tax_year if byvar==0, c(l) color(cranberry)
graph export ${dirout}/G_fig2d_payout.eps, replace
*list axes markers for graph
log on oneoffstats
disp "Fig 2d: C-corp y-axis markers"
disp 2*${byvar1premean_nonorm}
disp 1.5*${byvar1premean_nonorm}
disp 1*${byvar1premean_nonorm}
disp "Fig 2d: S-corp y-axis markers"
disp 2*${byvar0premean_nonorm}
disp 1.5*${byvar0premean_nonorm}
disp 1*${byvar0premean_nonorm}
log off oneoffstats

*MANUSCRIPT ONLY: IMMEDIATE RISE IN C-CORPORATION PAYOUTS IN FIG 2D
tab byvar if tax_year==2002, sum(resid)
tab byvar if tax_year==2003, sum(resid)
sum resid if byvar==0 & tax_year==2002
global scorp2002=r(mean)
sum resid if byvar==1 & tax_year==2002
global ccorp2002=r(mean)
sum resid if byvar==0 & tax_year==2003
global scorp2003=r(mean)
sum resid if byvar==1 & tax_year==2003
global ccorp2003=r(mean)
disp $ccorp2002-$scorp2002
disp $ccorp2003-$scorp2003
log on oneoffstats
disp "MANUSCRIPT ONLY: Immediate rise in C-corporation payouts in Fig 2d"
disp $ccorp2003-$scorp2003 - ($ccorp2002-$scorp2002)
log off oneoffstats

*MANUSCIPT ONLY: 2002 C-CORP PAYOUTS DATA POINT
log on oneoffstats
disp "MANUSCRIPT ONLY: 2002 C-corp payouts data point in Fig 2d"
disp ${ccorp2002}*${byvar1premean_nonorm}
log off oneoffstats




******************************************************************;
                     ************************;
*(3.3) MAIN FIGURE 3;
                     ************************;
******************************************************************;
global exhibit = "MF3"
global trimqtop = "p95"
global yvar = "inv"
global basevarroot = "penet"
global dflbyvar = "taxyearddccorpbin"
global dflbalanceacrossbyvar = 0
global dflvarlist = "nc2dig"
global dflorigwgtorig = "revlag2to1"
global cutvar = "revlag2to1"
global data = "soiubp_sizehetero"
global doyrbyyr = 0
global detrend = 0
global norm = 0
global dothrough2004only = 0
global cutvarnewdfl = 0
global dosizehetero=1

*RUN REGS AND SAVE TO divout_coeffs.dta
global row = 1
global yvar = "inv"
global basevarroot = "penet"
do ${dirdo}/div_analysis_fig3loop

global row = 2
global yvar = "penetdiff"
global basevarroot = "penet"
do ${dirdo}/div_analysis_fig3loop

global row = 3
global yvar = "employeecomp"
global basevarroot = "rev"
do ${dirdo}/div_analysis_fig3loop


*MAKE GRAPHS
**FIGURE 3a
use divout_coeffs if exhibit=="MT2" & column==2, clear
sum byvar1presd
global presd=r(mean)
use divout_coeffs if exhibit=="MF3" & row==1, clear
gen dd_top = dd+abs(invnorm(.05/10/2))*dd_se
gen dd_bot = dd-abs(invnorm(.05/10/2))*dd_se
keep dd dd_top dd_bot column
rename dd dd0
rename dd_top dd1
rename dd_bot dd2
rename column bin
reshape long dd, i(bin) j(level)
reg dd bin if level==0
predict ddfitted if level==0
egen xmin=min(bin), by(bin)
egen xmax=max(bin), by(bin)
gsort -xmin -xmax bin
global xmaxgraph = 10.5
global ymaxgraph = floor($presd/2*1000)/1000
global ymingraph = -$ymaxgraph
twoway scatter dd bin, c(L) m(+) ///
	graphregion(fcolor(white)) ///
	xlabel(.5(.5)$xmaxgraph) ylabel($ymingraph($ymaxgraph)$ymaxgraph) ///
	|| scatter ddfitted bin, c(l) m(i) color(black)	
graph export "${dirout}/G_fig3a_sizeheteroinv.eps", replace

**FIGURE 3b
use divout_coeffs if exhibit=="MT2" & column==8, clear
sum byvar1presd
global presd=r(mean)
use divout_coeffs if exhibit=="MF3" & row==2, clear
gen dd_top = dd+abs(invnorm(.05/10/2))*dd_se
gen dd_bot = dd-abs(invnorm(.05/10/2))*dd_se
keep dd dd_top dd_bot column
rename dd dd0
rename dd_top dd1
rename dd_bot dd2
rename column bin
reshape long dd, i(bin) j(level)
reg dd bin if level==0
predict ddfitted if level==0
egen xmin=min(bin), by(bin)
egen xmax=max(bin), by(bin)
gsort -xmin -xmax bin
global xmaxgraph = 10.5
global ymaxgraph = floor($presd/2*1000)/1000
global ymingraph = -$ymaxgraph
twoway scatter dd bin, c(L) m(+) ///
	graphregion(fcolor(white)) ///
	xlabel(.5(.5)$xmaxgraph) ylabel($ymingraph($ymaxgraph)$ymaxgraph) ///
	|| scatter ddfitted bin, c(l) m(i) color(black)	
graph export "${dirout}/G_fig3b_sizeheteronetinv.eps", replace

**FIGURE 3c
use divout_coeffs if exhibit=="MT2" & column==11, clear
sum byvar1presd
global presd=r(mean)
use divout_coeffs if exhibit=="MF3" & row==3, clear
gen dd_top = dd+abs(invnorm(.05/10/2))*dd_se
gen dd_bot = dd-abs(invnorm(.05/10/2))*dd_se
keep dd dd_top dd_bot column
rename dd dd0
rename dd_top dd1
rename dd_bot dd2
rename column bin
reshape long dd, i(bin) j(level)
reg dd bin if level==0
predict ddfitted if level==0
egen xmin=min(bin), by(bin)
egen xmax=max(bin), by(bin)
gsort -xmin -xmax bin
global xmaxgraph = 10.5
global ymaxgraph = floor($presd/2*1000)/1000
global ymingraph = -$ymaxgraph
twoway scatter dd bin, c(L) m(+) ///
	graphregion(fcolor(white)) ///
	xlabel(.5(.5)$xmaxgraph) ylabel($ymingraph($ymaxgraph)$ymaxgraph) ///
	|| scatter ddfitted bin, c(l) m(i) color(black)	
graph export "${dirout}/G_fig3c_sizeheterocomp.eps", replace


global endtime="$S_TIME"
disp "$starttime" " to " "$endtime"
capture log close _all




